@@ -1,14 +1,14 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "followupreminderjob.h"
 
+#include <Akonadi/KMime/MessageParts>
 #include <AkonadiCore/ItemFetchJob>
 #include <AkonadiCore/ItemFetchScope>
-#include <Akonadi/KMime/MessageParts>
 
 #include <KMime/Message>
 
@@ -19,8 +19,7 @@ FollowUpReminderJob::FollowUpReminderJob(QObject *parent)
 {
 }
 
-FollowUpReminderJob::~FollowUpReminderJob()
-= default;
+FollowUpReminderJob::~FollowUpReminderJob() = default;
 
 void FollowUpReminderJob::start()
 {
@@ -29,7 +28,7 @@ void FollowUpReminderJob::start()
         deleteLater();
         return;
     }
-    auto *job = new Akonadi::ItemFetchJob(mItem);
+    auto job = new Akonadi::ItemFetchJob(mItem);
     job->fetchScope().fetchPayloadPart(Akonadi::MessagePart::Envelope, true);
     job->fetchScope().setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
 
