@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,8 +7,8 @@
 #ifndef SENDLATERREMOVEMESSAGEJOB_H
 #define SENDLATERREMOVEMESSAGEJOB_H
 
-#include <QObject>
 #include <Item>
+#include <QObject>
 
 class KJob;
 
@@ -17,7 +17,7 @@ class SendLaterRemoveMessageJob : public QObject
     Q_OBJECT
 public:
     explicit SendLaterRemoveMessageJob(const QVector<Akonadi::Item::Id> &listItem, QObject *parent = nullptr);
-    ~SendLaterRemoveMessageJob();
+    ~SendLaterRemoveMessageJob() override;
 
     void start();
 
