@@ -14,7 +14,7 @@ class CreateFollowupReminderOnExistingMessageJobTest : public QObject
     Q_OBJECT
 public:
     explicit CreateFollowupReminderOnExistingMessageJobTest(QObject *parent = nullptr);
-    ~CreateFollowupReminderOnExistingMessageJobTest();
+    ~CreateFollowupReminderOnExistingMessageJobTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
     void shouldValidBeforeStartJob();
