@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2009-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2009-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,7 +7,8 @@
 #ifndef COLLECTIONTEMPLATESPAGE_H
 #define COLLECTIONTEMPLATESPAGE_H
 #include <AkonadiWidgets/collectionpropertiespage.h>
-namespace MailCommon {
+namespace MailCommon
+{
 class CollectionTemplatesWidget;
 }
 template<typename T> class QSharedPointer;
