@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -13,7 +13,7 @@
 ConfigurePluginPage::ConfigurePluginPage(QWidget *parent)
     : ConfigModule(parent)
 {
-    auto *l = new QHBoxLayout(this);
+    auto l = new QHBoxLayout(this);
     l->setContentsMargins({});
     mConfigurePlugins = new PimCommon::ConfigurePluginsWidget(new ConfigurePluginsListWidget(this), this);
     l->addWidget(mConfigurePlugins);
@@ -21,8 +21,7 @@ ConfigurePluginPage::ConfigurePluginPage(QWidget *parent)
     connect(mConfigurePlugins, &PimCommon::ConfigurePluginsWidget::changed, this, &ConfigurePluginPage::slotConfigureChanged);
 }
 
-ConfigurePluginPage::~ConfigurePluginPage()
-= default;
+ConfigurePluginPage::~ConfigurePluginPage() = default;
 
 void ConfigurePluginPage::save()
 {
