@@ -1,44 +1,45 @@
 /*
-  SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "configurepluginslistwidget.h"
 
+#include "../../plugininterface/kmailplugininterface.h"
 #include "kmail_debug.h"
 #include "util.h"
-#include "../../plugininterface/kmailplugininterface.h"
-#include <MessageViewer/ViewerPluginManager>
-#include <MessageViewer/HeaderStylePluginManager>
-#include <MessageComposer/PluginEditorCheckBeforeSendManager>
-#include <MessageComposer/PluginEditorInitManager>
-#include <MessageComposer/PluginEditorConvertTextManager>
-#include <MessageComposer/PluginEditorConvertText>
-#include <WebEngineViewer/NetworkUrlInterceptorPluginManager>
-#include <MessageComposer/PluginEditorGrammarManager>
-#include <PimCommon/GenericPluginManager>
 #include <AkonadiCore/ServerManager>
-#include <PimCommon/CustomToolsPlugin>
-#include <KSharedConfig>
 #include <KLocalizedString>
+#include <KSharedConfig>
+#include <MessageComposer/PluginEditorCheckBeforeSendManager>
+#include <MessageComposer/PluginEditorConvertText>
+#include <MessageComposer/PluginEditorConvertTextManager>
+#include <MessageComposer/PluginEditorGrammarManager>
+#include <MessageComposer/PluginEditorInitManager>
 #include <MessageComposer/PluginEditorManager>
+#include <MessageViewer/HeaderStylePluginManager>
+#include <MessageViewer/ViewerPluginManager>
+#include <PimCommon/CustomToolsPlugin>
+#include <PimCommon/GenericPluginManager>
+#include <WebEngineViewer/NetworkUrlInterceptorPluginManager>
 
-#include <QDBusInterface>
-#include <QDBusReply>
-#include <MessageComposer/PluginEditorInit>
-#include <WebEngineViewer/NetworkPluginUrlInterceptor>
+#include <AkonadiCore/AgentInstance>
+#include <AkonadiCore/AgentManager>
+#include <MessageComposer/PluginEditor>
 #include <MessageComposer/PluginEditorCheckBeforeSend>
+#include <MessageComposer/PluginEditorInit>
+#include <MessageViewer/HeaderStylePlugin>
+#include <MessageViewer/MessageViewerConfigureSettingsPlugin>
 #include <MessageViewer/MessageViewerConfigureSettingsPluginManager>
 #include <MessageViewer/ViewerPlugin>
 #include <PimCommon/GenericPlugin>
-#include <MessageComposer/PluginEditor>
-#include <MessageViewer/HeaderStylePlugin>
-#include <AkonadiCore/AgentManager>
-#include <AkonadiCore/AgentInstance>
-#include <MessageViewer/MessageViewerConfigureSettingsPlugin>
+#include <QDBusInterface>
+#include <QDBusReply>
+#include <WebEngineViewer/NetworkPluginUrlInterceptor>
 
-namespace {
+namespace
+{
 QString pluginEditorGroupName()
 {
     return QStringLiteral("plugineditorgroupname");
@@ -101,8 +102,7 @@ ConfigurePluginsListWidget::ConfigurePluginsListWidget(QWidget *parent)
     connect(this, &ConfigurePluginsListWidget::configureClicked, this, &ConfigurePluginsListWidget::slotConfigureClicked);
 }
 
-ConfigurePluginsListWidget::~ConfigurePluginsListWidget()
-= default;
+ConfigurePluginsListWidget::~ConfigurePluginsListWidget() = default;
 
 void ConfigurePluginsListWidget::save()
 {
@@ -172,7 +172,7 @@ void ConfigurePluginsListWidget::initialize()
 {
     mListWidget->clear();
 
-    //Load CheckBeforeSend
+    // Load CheckBeforeSend
     PimCommon::ConfigurePluginsListWidget::fillTopItems(MessageComposer::PluginEditorCheckBeforeSendManager::self()->pluginsDataList(),
                                                         i18n("Check Before Send Plugins"),
                                                         MessageComposer::PluginEditorCheckBeforeSendManager::self()->configGroupName(),
@@ -193,8 +193,8 @@ void ConfigurePluginsListWidget::initialize()
                                                         mPluginEditorGrammarItems,
                                                         pluginEditorGrammarGroupName());
 
-    //Load generic plugins
-    //Necessary to initialize plugin when we load it outside kmail
+    // Load generic plugins
+    // Necessary to initialize plugin when we load it outside kmail
     KMailPluginInterface::self()->initializePlugins();
     PimCommon::ConfigurePluginsListWidget::fillTopItems(KMailPluginInterface::self()->pluginsDataList(),
                                                         i18n("Tools Plugins"),
@@ -202,7 +202,7 @@ void ConfigurePluginsListWidget::initialize()
                                                         KMailPluginInterface::self()->configPrefixSettingKey(),
                                                         mPluginGenericItems,
                                                         kmailPluginToolsGroupName());
-    //Load plugin editor
+    // Load plugin editor
     PimCommon::ConfigurePluginsListWidget::fillTopItems(MessageComposer::PluginEditorManager::self()->pluginsDataList(),
                                                         i18n("Editor Plugins"),
                                                         MessageComposer::PluginEditorManager::self()->configGroupName(),
@@ -210,7 +210,7 @@ void ConfigurePluginsListWidget::initialize()
                                                         mPluginEditorItems,
                                                         pluginEditorGroupName());
 
-    //Load messageviewer plugin
+    // Load messageviewer plugin
     PimCommon::ConfigurePluginsListWidget::fillTopItems(MessageViewer::ViewerPluginManager::self()->pluginsDataList(),
                                                         i18n("Message Viewer"),
                                                         MessageViewer::ViewerPluginManager::self()->configGroupName(),
@@ -218,7 +218,7 @@ void ConfigurePluginsListWidget::initialize()
                                                         mPluginMessageViewerItems,
                                                         viewerPluginGroupName());
 
-    //Load webengineplugin
+    // Load webengineplugin
     PimCommon::ConfigurePluginsListWidget::fillTopItems(WebEngineViewer::NetworkUrlInterceptorPluginManager::self()->pluginsDataList(),
                                                         i18n("Webengine Plugins"),
                                                         WebEngineViewer::NetworkUrlInterceptorPluginManager::self()->configGroupName(),
@@ -226,14 +226,14 @@ void ConfigurePluginsListWidget::initialize()
                                                         mPluginWebEngineItems,
                                                         networkUrlInterceptorGroupName());
 
-    //Load headerstyle
+    // Load headerstyle
     PimCommon::ConfigurePluginsListWidget::fillTopItems(MessageViewer::HeaderStylePluginManager::self()->pluginsDataList(),
                                                         i18n("Header Style Plugins"),
                                                         MessageViewer::HeaderStylePluginManager::self()->configGroupName(),
                                                         MessageViewer::HeaderStylePluginManager::self()->configPrefixSettingKey(),
                                                         mPluginHeaderStyleItems,
                                                         headerStyleGroupName());
-    //Load Converter plugin
+    // Load Converter plugin
     PimCommon::ConfigurePluginsListWidget::fillTopItems(MessageComposer::PluginEditorConvertTextManager::self()->pluginsDataList(),
                                                         i18n("Text Conversion Plugins"),
                                                         MessageComposer::PluginEditorConvertTextManager::self()->configGroupName(),
@@ -246,9 +246,10 @@ void ConfigurePluginsListWidget::initialize()
                                                         MessageViewer::MessageViewerConfigureSettingsPluginManager::self()->configGroupName(),
                                                         MessageViewer::MessageViewerConfigureSettingsPluginManager::self()->configPrefixSettingKey(),
                                                         mPluginConfigureItems,
-                                                        configurePluginGroupName(), false);
+                                                        configurePluginGroupName(),
+                                                        false);
 
-    //Load Agent Plugin
+    // Load Agent Plugin
     initializeAgentPlugins();
     mListWidget->expandAll();
 }
@@ -294,8 +295,7 @@ PimCommon::PluginUtilData ConfigurePluginsListWidget::createAgentPluginData(cons
 
 bool ConfigurePluginsListWidget::agentActivateState(const QString &agentIdentifier, const QString &pathName)
 {
-    const QString service
-        = Akonadi::ServerManager::agentServiceName(Akonadi::ServerManager::Agent, agentIdentifier);
+    const QString service = Akonadi::ServerManager::agentServiceName(Akonadi::ServerManager::Agent, agentIdentifier);
     QDBusInterface interface(service, pathName);
     if (interface.isValid()) {
         QDBusReply<bool> enabled = interface.call(QStringLiteral("enabledAgent"));
@@ -314,8 +314,7 @@ bool ConfigurePluginsListWidget::agentActivateState(const QString &agentIdentifi
 void ConfigurePluginsListWidget::changeAgentActiveState(const QString &agentIdentifier, const QString &path, bool enable)
 {
     if (!agentIdentifier.isEmpty() && !path.isEmpty()) {
-        const QString service
-            = Akonadi::ServerManager::agentServiceName(Akonadi::ServerManager::Agent, agentIdentifier);
+        const QString service = Akonadi::ServerManager::agentServiceName(Akonadi::ServerManager::Agent, agentIdentifier);
         QDBusInterface interface(service, path);
         if (interface.isValid()) {
             interface.call(QStringLiteral("setEnableAgent"), enable);
@@ -332,7 +331,8 @@ void ConfigurePluginsListWidget::slotConfigureClicked(const QString &groupName,
             MessageViewer::HeaderStylePlugin *plugin = MessageViewer::HeaderStylePluginManager::self()->pluginFromIdentifier(identifier);
             plugin->showConfigureDialog(this);
         } else if (groupName == networkUrlInterceptorGroupName()) {
-            WebEngineViewer::NetworkPluginUrlInterceptor *plugin = WebEngineViewer::NetworkUrlInterceptorPluginManager::self()->pluginFromIdentifier(identifier);
+            WebEngineViewer::NetworkPluginUrlInterceptor *plugin =
+                WebEngineViewer::NetworkUrlInterceptorPluginManager::self()->pluginFromIdentifier(identifier);
             plugin->showConfigureDialog(this);
         } else if (groupName == viewerPluginGroupName()) {
             MessageViewer::ViewerPlugin *plugin = MessageViewer::ViewerPluginManager::self()->pluginFromIdentifier(identifier);
@@ -347,7 +347,8 @@ void ConfigurePluginsListWidget::slotConfigureClicked(const QString &groupName,
             MessageComposer::PluginEditorInit *plugin = MessageComposer::PluginEditorInitManager::self()->pluginFromIdentifier(identifier);
             plugin->showConfigureDialog(this);
         } else if (groupName == pluginEditorCheckBeforeGroupName()) {
-            MessageComposer::PluginEditorCheckBeforeSend *plugin = MessageComposer::PluginEditorCheckBeforeSendManager::self()->pluginFromIdentifier(identifier);
+            MessageComposer::PluginEditorCheckBeforeSend *plugin =
+                MessageComposer::PluginEditorCheckBeforeSendManager::self()->pluginFromIdentifier(identifier);
             plugin->showConfigureDialog(this);
         } else if (groupName == pluginEditorConvertTextGroupName()) {
             MessageComposer::PluginEditorConvertText *plugin = MessageComposer::PluginEditorConvertTextManager::self()->pluginFromIdentifier(identifier);
@@ -356,7 +357,8 @@ void ConfigurePluginsListWidget::slotConfigureClicked(const QString &groupName,
             PimCommon::CustomToolsPlugin *plugin = MessageComposer::PluginEditorGrammarManager::self()->pluginFromIdentifier(identifier);
             plugin->showConfigureDialog(this);
         } else if (groupName == configurePluginGroupName()) {
-            MessageViewer::MessageViewerConfigureSettingsPlugin *plugin = MessageViewer::MessageViewerConfigureSettingsPluginManager::self()->pluginFromIdentifier(identifier);
+            MessageViewer::MessageViewerConfigureSettingsPlugin *plugin =
+                MessageViewer::MessageViewerConfigureSettingsPluginManager::self()->pluginFromIdentifier(identifier);
             plugin->showConfigureDialog(this);
         } else if (groupName == agentAkonadiGroupName()) {
             for (const PimCommon::PluginUtilData &data : qAsConst(mPluginUtilDataList)) {
