@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2011-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2011-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,16 +7,16 @@
 #include "kmknotify.h"
 #include "kmkernel.h"
 
-#include <QVBoxLayout>
-#include <QComboBox>
-#include <KNotifyConfigWidget>
-#include <KLocalizedString>
 #include <KConfig>
-#include <KSeparator>
-#include <QStandardPaths>
-#include <QDialogButtonBox>
 #include <KConfigGroup>
+#include <KLocalizedString>
+#include <KNotifyConfigWidget>
+#include <KSeparator>
+#include <QComboBox>
+#include <QDialogButtonBox>
 #include <QPushButton>
+#include <QStandardPaths>
+#include <QVBoxLayout>
 
 using namespace KMail;
 
@@ -24,7 +24,7 @@ KMKnotify::KMKnotify(QWidget *parent)
     : QDialog(parent)
 {
     setWindowTitle(i18nc("@title:window", "Notification"));
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
 
     m_comboNotify = new QComboBox(this);
     m_comboNotify->setSizeAdjustPolicy(QComboBox::AdjustToContents);
@@ -36,7 +36,7 @@ KMKnotify::KMKnotify(QWidget *parent)
 
     mainLayout->addWidget(new KSeparator(this));
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -83,15 +83,12 @@ void KMKnotify::setCurrentNotification(const QString &name)
 
 void KMKnotify::initCombobox()
 {
-    const QStringList lstNotify = QStringList() << QStringLiteral("kmail2.notifyrc")
-                                                << QStringLiteral("akonadi_maildispatcher_agent.notifyrc")
-                                                << QStringLiteral("akonadi_mailfilter_agent.notifyrc")
-                                                << QStringLiteral("akonadi_archivemail_agent.notifyrc")
+    const QStringList lstNotify = QStringList() << QStringLiteral("kmail2.notifyrc") << QStringLiteral("akonadi_maildispatcher_agent.notifyrc")
+                                                << QStringLiteral("akonadi_mailfilter_agent.notifyrc") << QStringLiteral("akonadi_archivemail_agent.notifyrc")
                                                 << QStringLiteral("akonadi_sendlater_agent.notifyrc")
                                                 << QStringLiteral("akonadi_newmailnotifier_agent.notifyrc")
-                                                << QStringLiteral("akonadi_followupreminder_agent.notifyrc")
-                                                << QStringLiteral("messageviewer.notifyrc");
-    //TODO add other notifyrc here if necessary
+                                                << QStringLiteral("akonadi_followupreminder_agent.notifyrc") << QStringLiteral("messageviewer.notifyrc");
+    // TODO add other notifyrc here if necessary
 
     for (const QString &notify : lstNotify) {
         const QString fullPath = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("knotifications5/") + notify);
