@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -14,7 +14,7 @@ class SpellCheckerConfigDialog : public Sonnet::ConfigDialog
     Q_OBJECT
 public:
     explicit SpellCheckerConfigDialog(QWidget *parent = nullptr);
-    ~SpellCheckerConfigDialog();
+    ~SpellCheckerConfigDialog() override;
 
 private:
     void readConfig();
