@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,7 +8,8 @@
 #define KMAILPLUGINEDITORINITMANAGERINTERFACE_H
 
 #include <QObject>
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class RichTextComposer;
 }
 
@@ -17,7 +18,7 @@ class KMailPluginEditorInitManagerInterface : public QObject
     Q_OBJECT
 public:
     explicit KMailPluginEditorInitManagerInterface(QObject *parent = nullptr);
-    ~KMailPluginEditorInitManagerInterface() = default;
+    ~KMailPluginEditorInitManagerInterface() override = default;
 
     KPIMTextEdit::RichTextComposer *richTextEditor() const;
     void setRichTextEditor(KPIMTextEdit::RichTextComposer *richTextEditor);
@@ -26,6 +27,7 @@ public:
     void setParentWidget(QWidget *parentWidget);
 
     void initializePlugins();
+
 private:
     Q_DISABLE_COPY(KMailPluginEditorInitManagerInterface)
     KPIMTextEdit::RichTextComposer *mRichTextEditor = nullptr;
