@@ -1,14 +1,14 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "kmailplugineditormanagerinterface.h"
-#include <MessageComposer/PluginEditorManager>
-#include <MessageComposer/PluginEditor>
-#include <MessageComposer/PluginComposerInterface>
 #include "kmail_debug.h"
+#include <MessageComposer/PluginComposerInterface>
+#include <MessageComposer/PluginEditor>
+#include <MessageComposer/PluginEditorManager>
 
 #include <QAction>
 #include <QVector>
@@ -18,8 +18,7 @@ KMailPluginEditorManagerInterface::KMailPluginEditorManagerInterface(QObject *pa
 {
 }
 
-KMailPluginEditorManagerInterface::~KMailPluginEditorManagerInterface()
-= default;
+KMailPluginEditorManagerInterface::~KMailPluginEditorManagerInterface() = default;
 
 KPIMTextEdit::RichTextEditor *KMailPluginEditorManagerInterface::richTextEditor() const
 {
@@ -58,8 +57,8 @@ void KMailPluginEditorManagerInterface::initializePlugins()
     const QVector<MessageComposer::PluginEditor *> lstPlugin = MessageComposer::PluginEditorManager::self()->pluginsList();
     for (MessageComposer::PluginEditor *plugin : lstPlugin) {
         if (plugin->isEnabled()) {
-            auto *interface = static_cast<MessageComposer::PluginEditorInterface *>(plugin->createInterface(this));
-            auto *composerInterface = new MessageComposer::PluginComposerInterface;
+            auto interface = static_cast<MessageComposer::PluginEditorInterface *>(plugin->createInterface(this));
+            auto composerInterface = new MessageComposer::PluginComposerInterface;
             composerInterface->setComposerViewBase(mComposerInterface);
             interface->setComposerInterface(composerInterface);
             interface->setRichTextEditor(mRichTextEditor);
@@ -118,6 +117,17 @@ QList<QAction *> KMailPluginEditorManagerInterface::actionsType(MessageComposer:
     return mActionHash.value(type);
 }
 
+void KMailPluginEditorManagerInterface::setStatusBarWidgetEnabled(MessageComposer::PluginEditorInterface::ApplyOnFieldType type)
+{
+    if (!mStatusBarWidget.isEmpty()) {
+        for (MessageComposer::PluginEditorInterface *interface : qAsConst(mListPluginInterface)) {
+            if (auto w = interface->statusBarWidget()) {
+                w->setEnabled((interface->applyOnFieldTypes() & type));
+            }
+        }
+    }
+}
+
 QList<QWidget *> KMailPluginEditorManagerInterface::statusBarWidgetList()
 {
     if (mStatusBarWidget.isEmpty() && !mListPluginInterface.isEmpty()) {
@@ -130,7 +140,7 @@ QList<QWidget *> KMailPluginEditorManagerInterface::statusBarWidgetList()
     return mStatusBarWidget;
 }
 
-QHash<MessageComposer::PluginActionType::Type, QList<QAction *> > KMailPluginEditorManagerInterface::actionsType()
+QHash<MessageComposer::PluginActionType::Type, QList<QAction *>> KMailPluginEditorManagerInterface::actionsType()
 {
     if (mActionHash.isEmpty() && !mListPluginInterface.isEmpty()) {
         for (MessageComposer::PluginEditorInterface *interface : qAsConst(mListPluginInterface)) {
@@ -138,13 +148,13 @@ QHash<MessageComposer::PluginActionType::Type, QList<QAction *> > KMailPluginEdi
             MessageComposer::PluginActionType::Type type = actionType.type();
             const bool needSelectedText = interface->needSelectedText();
             if (needSelectedText) {
-                //Disable by default as we don't have selection by default.
+                // Disable by default as we don't have selection by default.
                 actionType.action()->setEnabled(false);
                 connect(this, &KMailPluginEditorManagerInterface::textSelectionChanged, actionType.action(), &QAction::setEnabled);
             }
             QList<QAction *> lst = mActionHash.value(type);
             if (!lst.isEmpty()) {
-                auto *act = new QAction(this);
+                auto act = new QAction(this);
                 act->setSeparator(true);
                 lst << act << actionType.action();
                 mActionHash.insert(type, lst);
@@ -155,7 +165,7 @@ QHash<MessageComposer::PluginActionType::Type, QList<QAction *> > KMailPluginEdi
                 type = MessageComposer::PluginActionType::PopupMenu;
                 lst = mActionHash.value(type);
                 if (!lst.isEmpty()) {
-                    auto *act = new QAction(this);
+                    auto act = new QAction(this);
                     act->setSeparator(true);
                     lst << act << actionType.action();
                     mActionHash.insert(type, lst);
@@ -167,7 +177,7 @@ QHash<MessageComposer::PluginActionType::Type, QList<QAction *> > KMailPluginEdi
                 type = MessageComposer::PluginActionType::ToolBar;
                 lst = mActionHash.value(type);
                 if (!lst.isEmpty()) {
-                    auto *act = new QAction(this);
+                    auto act = new QAction(this);
                     act->setSeparator(true);
                     lst << act << actionType.action();
                     mActionHash.insert(type, lst);
