@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -7,24 +7,24 @@
 
 #include "potentialphishingdetaildialog.h"
 #include "potentialphishingdetailwidget.h"
-#include <KSharedConfig>
-#include <KLocalizedString>
 #include <KConfigGroup>
-#include <QVBoxLayout>
-#include <QPushButton>
+#include <KLocalizedString>
+#include <KSharedConfig>
 #include <QDialogButtonBox>
+#include <QPushButton>
+#include <QVBoxLayout>
 
 PotentialPhishingDetailDialog::PotentialPhishingDetailDialog(QWidget *parent)
     : QDialog(parent)
 {
     setWindowTitle(i18nc("@title:window", "Details"));
-    auto *topLayout = new QVBoxLayout(this);
+    auto topLayout = new QVBoxLayout(this);
     setModal(true);
 
     mPotentialPhishingDetailWidget = new PotentialPhishingDetailWidget(this);
     mPotentialPhishingDetailWidget->setObjectName(QStringLiteral("potentialphising_widget"));
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
