@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -17,7 +17,7 @@ class KMAILTESTS_TESTS_EXPORT PotentialPhishingEmailJob : public QObject
     Q_OBJECT
 public:
     explicit PotentialPhishingEmailJob(QObject *parent = nullptr);
-    ~PotentialPhishingEmailJob();
+    ~PotentialPhishingEmailJob() override;
 
     void setEmailWhiteList(const QStringList &emails);
     void setPotentialPhishingEmails(const QStringList &emails);
