@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -8,14 +8,14 @@
 #ifndef POTENTIALPHISHINGEMAILWARNING_H
 #define POTENTIALPHISHINGEMAILWARNING_H
 
-#include <KMessageWidget>
 #include "kmail_private_export.h"
+#include <KMessageWidget>
 class KMAILTESTS_TESTS_EXPORT PotentialPhishingEmailWarning : public KMessageWidget
 {
     Q_OBJECT
 public:
     explicit PotentialPhishingEmailWarning(QWidget *parent = nullptr);
-    ~PotentialPhishingEmailWarning();
+    ~PotentialPhishingEmailWarning() override;
 
     void setPotentialPhisingEmail(const QStringList &lst);
 
