@@ -1,13 +1,13 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #ifndef FOLDERARCHIVEAGENTCHECKCOLLECTION_H
 #define FOLDERARCHIVEAGENTCHECKCOLLECTION_H
-#include <QObject>
 #include <AkonadiCore/Collection>
 #include <QDate>
+#include <QObject>
 class KJob;
 class FolderArchiveAccountInfo;
 class FolderArchiveAgentCheckCollection : public QObject
@@ -15,7 +15,7 @@ class FolderArchiveAgentCheckCollection : public QObject
     Q_OBJECT
 public:
     explicit FolderArchiveAgentCheckCollection(FolderArchiveAccountInfo *info, QObject *parent = nullptr);
-    ~FolderArchiveAgentCheckCollection();
+    ~FolderArchiveAgentCheckCollection() override;
 
     void start();
 
