@@ -1,13 +1,13 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #ifndef FOLDERARCHIVEAGENTJOB_H
 #define FOLDERARCHIVEAGENTJOB_H
 
-#include <QObject>
 #include <AkonadiCore/Item>
+#include <QObject>
 class KJob;
 class FolderArchiveAccountInfo;
 class FolderArchiveManager;
@@ -16,8 +16,11 @@ class FolderArchiveAgentJob : public QObject
 {
     Q_OBJECT
 public:
-    explicit FolderArchiveAgentJob(FolderArchiveManager *manager, FolderArchiveAccountInfo *info, const Akonadi::Item::List &lstItem, QObject *parent = nullptr);
-    ~FolderArchiveAgentJob();
+    explicit FolderArchiveAgentJob(FolderArchiveManager *manager,
+                                   FolderArchiveAccountInfo *info,
+                                   const Akonadi::Item::List &lstItem,
+                                   QObject *parent = nullptr);
+    ~FolderArchiveAgentJob() override;
 
     void start();
 
