@@ -1,15 +1,15 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #ifndef FOLDERARCHIVECACHE_H
 #define FOLDERARCHIVECACHE_H
 
-#include <QObject>
+#include <AkonadiCore/Collection>
 #include <QDateTime>
 #include <QHash>
-#include <AkonadiCore/Collection>
+#include <QObject>
 
 class FolderArchiveAccountInfo;
 
@@ -23,7 +23,7 @@ class FolderArchiveCache : public QObject
     Q_OBJECT
 public:
     explicit FolderArchiveCache(QObject *parent = nullptr);
-    ~FolderArchiveCache();
+    ~FolderArchiveCache() override;
 
     void addToCache(const QString &resourceName, Akonadi::Collection::Id id);
 
