@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -17,21 +17,17 @@ class KMAILTESTS_TESTS_EXPORT IdentityAddVcardDialog : public QDialog
 {
     Q_OBJECT
 public:
-    enum DuplicateMode {
-        Empty,
-        ExistingEntry,
-        FromExistingVCard
-    };
+    enum DuplicateMode { Empty, ExistingEntry, FromExistingVCard };
 
     explicit IdentityAddVcardDialog(const QStringList &shadowIdentities, QWidget *parent = nullptr);
-    ~IdentityAddVcardDialog();
+    ~IdentityAddVcardDialog() override;
 
     Q_REQUIRED_RESULT DuplicateMode duplicateMode() const;
     Q_REQUIRED_RESULT QString duplicateVcardFromIdentity() const;
     Q_REQUIRED_RESULT QUrl existingVCard() const;
 
 private:
-    QButtonGroup *mButtonGroup = nullptr;
+    QButtonGroup *const mButtonGroup;
     QComboBox *mComboBox = nullptr;
     KUrlRequester *mVCardPath = nullptr;
 };
