@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -22,8 +22,7 @@ AddEmailToExistingContactJob::AddEmailToExistingContactJob(const Akonadi::Item &
     KContacts::Addressee::parseEmailAddress(email, name, mEmail);
 }
 
-AddEmailToExistingContactJob::~AddEmailToExistingContactJob()
-= default;
+AddEmailToExistingContactJob::~AddEmailToExistingContactJob() = default;
 
 void AddEmailToExistingContactJob::start()
 {
@@ -36,12 +35,12 @@ void AddEmailToExistingContactJob::start()
             emails.append(mEmail);
             address.setEmails(emails);
             mItem.setPayload<KContacts::Addressee>(address);
-            auto *job = new Akonadi::ItemModifyJob(mItem);
+            auto job = new Akonadi::ItemModifyJob(mItem);
             connect(job, &Akonadi::ItemModifyJob::result, this, &AddEmailToExistingContactJob::slotAddEmailDone);
         }
     } else {
         qCDebug(KMAIL_LOG) << " not a KContacts::Addressee item ";
-        //TODO add error
+        // TODO add error
         emitResult();
     }
 }
