@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,7 +13,7 @@ class KMLaunchExternalComponent : public QObject
     Q_OBJECT
 public:
     explicit KMLaunchExternalComponent(QWidget *parentWidget, QObject *parent = nullptr);
-    ~KMLaunchExternalComponent();
+    ~KMLaunchExternalComponent() override;
 
 public Q_SLOTS:
     void slotConfigureSendLater();
@@ -26,6 +26,7 @@ public Q_SLOTS:
     void slotImport();
     void slotAccountWizard();
     void slotFilterLogViewer();
+
 private:
     Q_DISABLE_COPY(KMLaunchExternalComponent)
     QWidget *const mParentWidget;
