@@ -10,15 +10,16 @@
 #ifndef KMAIL_SECONDARYWINDOW_H
 #define KMAIL_SECONDARYWINDOW_H
 
-#include <kxmlguiwindow.h>
 #include "kmail_private_export.h"
+#include <kxmlguiwindow.h>
 class QCloseEvent;
 
-namespace KMail {
+namespace KMail
+{
 /**
-   *  Window class for secondary KMail window like the composer window and
-   *  the separate message window.
-   */
+ *  Window class for secondary KMail window like the composer window and
+ *  the separate message window.
+ */
 class KMAILTESTS_TESTS_EXPORT SecondaryWindow : public KXmlGuiWindow
 {
     Q_OBJECT
