@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2011-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2011-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,12 +7,12 @@
 #ifndef TAGSELECTDIALOG_H
 #define TAGSELECTDIALOG_H
 
+#include "MailCommon/Tag"
 #include "kmail_private_export.h"
-#include <QDialog>
-#include <QVector>
 #include <AkonadiCore/Item>
 #include <AkonadiCore/Tag>
-#include "MailCommon/Tag"
+#include <QDialog>
+#include <QVector>
 
 class QListWidget;
 class KActionCollection;
@@ -21,7 +21,7 @@ class KMAILTESTS_TESTS_EXPORT TagSelectDialog : public QDialog
     Q_OBJECT
 public:
     explicit TagSelectDialog(QWidget *parent, int numberOfSelectedMessages, const Akonadi::Item &selectedItem);
-    ~TagSelectDialog();
+    ~TagSelectDialog() override;
     Q_REQUIRED_RESULT Akonadi::Tag::List selectedTag() const;
 
     void setActionCollection(const QList<KActionCollection *> &actionCollectionList);
@@ -32,9 +32,7 @@ private:
     void writeConfig();
     void readConfig();
     void createTagList(bool updateList);
-    enum ItemType {
-        UrlTag = Qt::UserRole + 1
-    };
+    enum ItemType { UrlTag = Qt::UserRole + 1 };
     const int mNumberOfSelectedMessages = -1;
     const Akonadi::Item mSelectedItem;
 
