@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -12,8 +12,7 @@ ZoomLabelWidget::ZoomLabelWidget(QWidget *parent)
 {
 }
 
-ZoomLabelWidget::~ZoomLabelWidget()
-= default;
+ZoomLabelWidget::~ZoomLabelWidget() = default;
 
 void ZoomLabelWidget::setZoom(qreal zoomFactor)
 {
